==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/kbibtexselectstring.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#include <qlabel.h>
#include <qlistview.h>
#include <kdialogbase.h>
#include <klocale.h>

#include <bibtexfile.h>
#include <bibtexstring.h>
#include "kbibtexselectstring.h"

KBibTeXSelectString::KBibTeXSelectString( BibTeXFile * bibTeXFile, QWidget *parent, const char *name )
        : QVBox( parent, name )
{
    setSpacing( KDialog::spacingHint() );
    setMinimumWidth( 384 );

    QLabel *label = new QLabel( i18n( "Select &macro:" ), this );
    m_listViewStrings = new QListView( this );

    m_listViewStrings->addColumn( i18n( "Name" ) );
    m_listViewStrings->addColumn( i18n( "Value" ) );
    m_listViewStrings ->setAllColumnsShowFocus(true);
    label->setBuddy( m_listViewStrings );

    for ( unsigned int i = 0; i < bibTeXFile->count(); i++ )
    {
        BibTeXString* string = dynamic_cast<BibTeXString*>( bibTeXFile->at( i ) );
        if ( string )
        {
            new QListViewItem( m_listViewStrings, string->key(), string->value() );
        }
    }
}


KBibTeXSelectString::~KBibTeXSelectString()
{}

QString KBibTeXSelectString::execute( BibTeXFile * bibTeXFile, QWidget *parent, const char *name )
{
    QString result = QString::null;

    KDialogBase * dlg = new KDialogBase( parent, name, true, i18n( "Select Macro" ), KDialogBase::Ok | KDialogBase::Cancel );
    KBibTeXSelectString *selectStrings = new KBibTeXSelectString( bibTeXFile, dlg, name );
    dlg->setMainWidget( selectStrings );

    if ( ( dlg->exec() == QDialog::Accepted ) && ( selectStrings->m_listViewStrings->currentItem() ) )
        result = selectStrings->m_listViewStrings->currentItem() ->text( 0 );

    delete selectStrings;
    delete dlg;

    return result;
}

#include "kbibtexselectstring.moc"

==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/kbibtexselectstring.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#include <qlabel.h>
#include <qlistview.h>
#include <kdialogbase.h>
#include <klocale.h>

#include <bibtexfile.h>
#include <bibtexstring.h>
#include "kbibtexselectstring.h"

KBibTeXSelectString::KBibTeXSelectString( BibTeX::BibTeXFile * bibTeXFile, QWidget *parent, const char *name )
        : QVBox( parent, name )
{
    setSpacing( KDialog::spacingHint() );
    setMinimumWidth( 384 );

    QLabel *label = new QLabel( i18n( "Select &macro:" ), this );
    m_listViewStrings = new QListView( this );

    m_listViewStrings->addColumn( i18n( "Name" ) );
    m_listViewStrings->addColumn( i18n( "Value" ) );
    m_listViewStrings ->setAllColumnsShowFocus( true );
    label->setBuddy( m_listViewStrings );

    for ( unsigned int i = 0; i < bibTeXFile->count(); i++ )
    {
        BibTeX::BibTeXString* string = dynamic_cast<BibTeX::BibTeXString*>( bibTeXFile->at( i ) );
        if ( string && string->begin() != string->end() )
        {
            BibTeX::BibTeXElement::FieldItem item = *( string->begin() );
            if ( !item.isStringKey )
                new QListViewItem( m_listViewStrings, string->key(), item.text );

        }
    }
}


KBibTeXSelectString::~KBibTeXSelectString()
{}

QString KBibTeXSelectString::execute( BibTeX::BibTeXFile * bibTeXFile, QWidget *parent, const char *name )
{
    QString result = QString::null;

    KDialogBase * dlg = new KDialogBase( parent, name, true, i18n( "Select Macro" ), KDialogBase::Ok | KDialogBase::Cancel );
    KBibTeXSelectString *selectStrings = new KBibTeXSelectString( bibTeXFile, dlg, name );
    dlg->setMainWidget( selectStrings );

    if ( ( dlg->exec() == QDialog::Accepted ) && ( selectStrings->m_listViewStrings->currentItem() ) )
        result = selectStrings->m_listViewStrings->currentItem() ->text( 0 );

    delete selectStrings;
    delete dlg;

    return result;
}

#include "kbibtexselectstring.moc"
